@@ -5,7 +5,7 @@
 // +---------------------------------------------------------------------------+
 // | geeklog/plugins/dbman/install_defaults.php                                |
 // +---------------------------------------------------------------------------+
-// | Copyright (C) 2011 mystral-kk - geeklog AT mystral-kk DOT net             |
+// | Copyright (C) 2011-2014 mystral-kk - geeklog AT mystral-kk DOT net        |
 // |                                                                           |
 // | Constructed with the Universal Plugin                                     |
 // +---------------------------------------------------------------------------+
@@ -26,8 +26,8 @@
 // |                                                                           |
 // +---------------------------------------------------------------------------+
 
-if (strpos(strtolower($_SERVER['PHP_SELF']), strtolower(basename(__FILE__))) !== FALSE) {
-    die('This file can not be used on its own!');
+if (stripos($_SERVER['PHP_SELF'], basename(__FILE__)) !== false) {
+    die('This file cannot be used on its own!');
 }
 
 /**
@@ -46,67 +46,49 @@ $_DBMAN_DEFAULT = array();
 // Main settings
 //===============================================
 
-/**
-* the flag to decide whether to allow restoration in Dbman plugin.
-* SHOULD BE FALSE TO PREVENT ACCIDENTAL DAMAGE TO DATABASE.  SET THIS OPTION TO
-* TRUE ONLY IF YOU KNOW WHAT YOU DO.  YOU HAVE BEEN WARNED!
-*/
-$_DBMAN_DEFAULT['allow_restore'] = FALSE;
+// The flag to decide whether to allow restoration in Dbman plugin.  SHOULD BE
+// false TO PREVENT ACCIDENTAL DAMAGE TO DATABASE.  SET THIS OPTION TO true
+// ONLY IF YOU KNOW WHAT YOU DO.  YOU HAVE BEEN WARNED!
+$_DBMAN_DEFAULT['allow_restore'] = false;
 
-/**
-* the number of records to select data from database when the dbman plugin
-* backups a table.  If "MySQL client run out of memory." error occurs,
-* decrease this value
-*/
+// The number of records to select data from database when the dbman plugin
+// backups a table.  If "MySQL client run out of memory." error occurs, decrease
+// this value
 $_DBMAN_DEFAULT['chunk_size'] = 100;
 
-/**
-* the flag to indicate compression level:
-* valid values: 1 (largest size) - 9 (smallest size)
-*/
+// The flag to indicate compression level:
+// valid values: 1 (largest size) - 9 (smallest size)
 $_DBMAN_DEFAULT['compression_level'] = 8;
 
-/**
-* table names which the Dbman plugin shouldn't backup the data of (table
-* structures will always be backupped).  You can use regular expressions
-* (preg_match() style) to designate table name(s).
-* e.g. "/^{$_DB_table_prefix}sessions_/"
-*/
+// Table names which the Dbman plugin shouldn't backup the data of (table
+// structures will always be backupped).  You can use regular expressions
+// (preg_match() style) to designate table name(s).
+// e.g. "/^{$_DB_table_prefix}sessions_/"
 $_DBMAN_DEFAULT['backup_except']   = array();
 $_DBMAN_DEFAULT['backup_except'][] = "/^{$_DB_table_prefix}gus_/";
 
-/**
-* the flag to decide whether to backup with psedo-cron
-*/
-$_DBMAN_DEFAULT['cron_backup'] = FALSE;
+// The flag to decide whether to backup with psedo-cron
+$_DBMAN_DEFAULT['cron_backup'] = false;
 
-/**
-* Maximum number of backup files to be kept.  When set to 0, no backup file
-* will be deleted.
-*/
+// Maximum number of backup files to be kept.  When set to 0, no backup file
+// will be deleted.
 $_DBMAN_DEFAULT['max_backup'] = 0;
 
 //===============================================
 // Default settings for backup
 //===============================================
 
-/**
-* the flag to decide whether to add "DROP TABLE IF EXISTS ...".
-* For the compatibility with PhpMyAdminin, this should be set false.
-*/
-$_DBMAN_DEFAULT['add_drop_table'] = FALSE;
+// The flag to decide whether to add "DROP TABLE IF EXISTS ...".  For the
+// compatibility with PhpMyAdminin, this should be set false.
+$_DBMAN_DEFAULT['add_drop_table'] = false;
 
-/**
-* the flag to decide whether to compress backup files.  If set true, the
-* dbman plugin tries to compress the data with Zlib.  In this case,
-* names of backup files are '*.sql.gz'.
-*/
-$_DBMAN_DEFAULT['compress_data'] = FALSE;
+// The flag to decide whether to compress backup files.  If set true, the dbman
+// plugin tries to compress the data with Zlib.  In this case, names of backup
+// files are '*.sql.gz'.
+$_DBMAN_DEFAULT['compress_data'] = false;
 
-/**
-* the flag to decide whether to download backup files.
-*/
-$_DBMAN_DEFAULT['download_as_file'] = FALSE;
+// The flag to decide whether to download backup files.
+$_DBMAN_DEFAULT['download_as_file'] = false;
 
 /**
 * Initializes Dbman plugin configuration
@@ -116,7 +98,7 @@ $_DBMAN_DEFAULT['download_as_file'] = FALSE;
 * if available (e.g. from an old config.php), uses $_DBMAN_DEFAULT
 * otherwise.
 *
-* @return   boolean     TRUE: success; FALSE: an error occurred
+* @return   boolean     true: success; false: an error occurred
 */
 function plugin_initconfig_dbman() {
     global $_DBMAN_DEFAULT;
@@ -125,23 +107,23 @@ function plugin_initconfig_dbman() {
     $c = config::get_instance();
 	
     if (!$c->group_exists($me)) {
-        $c->add('sg_main', NULL, 'subgroup', 0, 0, NULL, 0, TRUE, $me);
-        $c->add('fs_main', NULL, 'fieldset', 0, 0, NULL, 1, TRUE, $me);
-        $c->add('fs_backup', NULL, 'fieldset', 0, 1, NULL, 2, TRUE, $me);
+        $c->add('sg_main', null, 'subgroup', 0, 0, null, 0, true, $me);
+        $c->add('fs_main', null, 'fieldset', 0, 0, null, 1, true, $me);
+        $c->add('fs_backup', null, 'fieldset', 0, 1, null, 2, true, $me);
 		
 		// Main settings
-        $c->add('allow_restore', $_DBMAN_DEFAULT['allow_restore'], 'select', 0, 0, 0, 110, TRUE, $me);
-        $c->add('chunk_size', $_DBMAN_DEFAULT['chunk_size'], 'text', 0, 0, NULL, 120, TRUE, $me);
-        $c->add('compression_level', $_DBMAN_DEFAULT['compression_level'], 'select', 0, 0, 1, 130, TRUE, $me);
-        $c->add('backup_except', $_DBMAN_DEFAULT['backup_except'], '%text', 0, 0, NULL, 140, TRUE, $me);
-        $c->add('cron_backup', $_DBMAN_DEFAULT['cron_backup'], 'select', 0, 0, 0, 150, TRUE, $me);
-        $c->add('max_backup', $_DBMAN_DEFAULT['max_backup'], 'text', 0, 0, NULL, 160, TRUE, $me);
+        $c->add('allow_restore', $_DBMAN_DEFAULT['allow_restore'], 'select', 0, 0, 0, 110, true, $me);
+        $c->add('chunk_size', $_DBMAN_DEFAULT['chunk_size'], 'text', 0, 0, null, 120, true, $me);
+        $c->add('compression_level', $_DBMAN_DEFAULT['compression_level'], 'select', 0, 0, 1, 130, true, $me);
+        $c->add('backup_except', $_DBMAN_DEFAULT['backup_except'], '%text', 0, 0, null, 140, true, $me);
+        $c->add('cron_backup', $_DBMAN_DEFAULT['cron_backup'], 'select', 0, 0, 0, 150, true, $me);
+        $c->add('max_backup', $_DBMAN_DEFAULT['max_backup'], 'text', 0, 0, null, 160, true, $me);
 		
 		// Default settings for backup
-        $c->add('add_drop_table', $_DBMAN_DEFAULT['add_drop_table'], 'select', 0, 1, 0, 210, TRUE, $me);
-        $c->add('compress_data', $_DBMAN_DEFAULT['compress_data'], 'select', 0, 1, 0, 220, TRUE, $me);
-        $c->add('download_as_file', $_DBMAN_DEFAULT['download_as_file'], 'select', 0, 1, 0, 230, TRUE, $me);
+        $c->add('add_drop_table', $_DBMAN_DEFAULT['add_drop_table'], 'select', 0, 1, 0, 210, true, $me);
+        $c->add('compress_data', $_DBMAN_DEFAULT['compress_data'], 'select', 0, 1, 0, 220, true, $me);
+        $c->add('download_as_file', $_DBMAN_DEFAULT['download_as_file'], 'select', 0, 1, 0, 230, true, $me);
     }
 	
-    return TRUE;
+    return true;
 }
