@@ -38,7 +38,7 @@
 
 $_SQL[] = "
 CREATE TABLE [dbo].[{$_TABLES['staticpage']}] (
-    [sp_id] [varchar] (40) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
+    [sp_id] [varchar] (128) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
     [sp_title] [varchar] (128) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
     [sp_page_title] [varchar] (128) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
     [sp_content] [varchar] (5000) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
@@ -53,6 +53,7 @@ CREATE TABLE [dbo].[{$_TABLES['staticpage']}] (
     [meta_keywords] [varchar] (5000) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
     [template_flag] [tinyint] NULL ,
     [template_id] [varchar] (40) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
+    [cache_time] [int] NOT NULL ,
     [draft_flag] [tinyint] NULL ,
     [owner_id] [numeric](8, 0) NOT NULL ,
     [group_id] [numeric](8, 0) NOT NULL ,
@@ -62,7 +63,6 @@ CREATE TABLE [dbo].[{$_TABLES['staticpage']}] (
     [perm_anon] [tinyint] NOT NULL ,
     [sp_centerblock] [tinyint] NOT NULL ,
     [sp_help] [varchar] (256) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
-    [sp_tid] [varchar] (20) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL ,
     [sp_where] [tinyint] NOT NULL ,
     [sp_php] [tinyint] NOT NULL ,
     [sp_nf] [tinyint] NULL ,
@@ -73,6 +73,7 @@ CREATE TABLE [dbo].[{$_TABLES['staticpage']}] (
 
 $_SQL[] = "ALTER TABLE [dbo].[{$_TABLES['staticpage']}] ADD
     CONSTRAINT [DF_{$_TABLES['staticpage']}] DEFAULT ('html') FOR [postmode],
+    CONSTRAINT [DF_{$_TABLES['staticpage']}] DEFAULT ('0') FOR [cache_time],
 	CONSTRAINT [PK_{$_TABLES['staticpage']}] PRIMARY KEY  CLUSTERED
 	(
 		[sp_id]
