@@ -44,7 +44,6 @@ $sure  = isset($_REQUEST['sure']) ? COM_applyFilter($_REQUEST['sure'])  : '';
 
 // Initialise output variable
 $display = '';
-$display .= COM_siteHeader();
 
 // Debug Code to show variables
 $display .= gf_showVariables();
@@ -68,18 +67,17 @@ if ($op == 'banip' && $ip != '') {
         COM_output($display);
         exit;
     } else {
-        $ips_unban = new Template($CONF_FORUM['path_layout'] . 'forum/layout/admin');
-        $ips_unban->set_file (array ('ips_unban'=>'ips_unban.thtml'));
-        $ips_unban->set_var ('xhtml', XHTML);
-        $ips_unban->set_var ('phpself', $_CONF['site_admin_url'] .'/plugins/forum/ips.php');
-        $ips_unban->set_var ('ip', $ip);
-        $ips_unban->set_var ('msg1', $LANG_GF96['banip']);
-        $ips_unban->set_var ('msg2', sprintf($LANG_GF96['banipmsg'], $ip));
-        $ips_unban->set_var ('ban', $LANG_GF96['ban']);
+        $ips_unban = COM_newTemplate($CONF_FORUM['path_layout'] . 'forum/layout/admin');
+        $ips_unban->set_file(array ('ips_unban'=>'ips_unban.thtml'));
+        $ips_unban->set_var('phpself', $_CONF['site_admin_url'] .'/plugins/forum/ips.php');
+        $ips_unban->set_var('ip', $ip);
+        $ips_unban->set_var('msg1', $LANG_GF96['banip']);
+        $ips_unban->set_var('msg2', sprintf($LANG_GF96['banipmsg'], $ip));
+        $ips_unban->set_var('ban', $LANG_GF96['ban']);
         $ips_unban->set_var('gltoken_name', CSRF_TOKEN);
         $ips_unban->set_var('gltoken', SEC_createToken());
-        $ips_unban->parse ('output', 'ips_unban');
-        $display .= $ips_unban->finish ($ips_unban->get_var('output'));
+        $ips_unban->parse('output', 'ips_unban');
+        $display .= $ips_unban->finish($ips_unban->get_var('output'));
     }
 } else if ($op == 'unban' && $ip != '' && SEC_checkToken()) {
     // Remove the entry from the database
@@ -93,40 +91,39 @@ if ($op == 'banip' && $ip != '') {
     // Show the list of banned IPs and quit
     $bannedsql = DB_query("SELECT * FROM {$_TABLES['forum_banned_ip']} ORDER BY host_ip DESC");
     $bannum = DB_numRows($bannedsql);
-    $p = new Template($CONF_FORUM['path_layout'] . 'forum/layout/admin');
-    $p->set_file (array ('page' => 'banip_mgmt.thtml', 'records' => 'ip_records.thtml'));
-    $p->set_var ('xhtml', XHTML);
+    $p = COM_newTemplate($CONF_FORUM['path_layout'] . 'forum/layout/admin');
+    $p->set_file(array ('page' => 'banip_mgmt.thtml', 'records' => 'ip_records.thtml'));
     if ($bannum == 0) {
-        $p->set_var ('alertmessage', $LANG_GF96['noips']);
-        $p->set_var ('showalert','');
+        $p->set_var('alertmessage', $LANG_GF96['noips']);
+        $p->set_var('showalert','');
     } else {
-        $p->set_var ('showalert','none');
+        $p->set_var('showalert','none');
     }
-    $p->set_var ('phpself', $_CONF['site_admin_url'] .'/plugins/forum/ips.php');
-    $p->set_var ('lang_noip', $LANG_GF96['noip']);
-    $p->set_var ('LANG_IP',$LANG_GF96['ipbanned']);
-    $p->set_var ('lang_ban', $LANG_GF96['ban']);
-    $p->set_var ('lang_ip2', $LANG_GF96['ip']);
-    $p->set_var ('legend', $LANG_GF96['enterip']);
-    $p->set_var ('msg', $LANG_GF96['banipmsg']);
-    $p->set_var ('LANG_Actions', $LANG_GF01['ACTIONS']);
+    $p->set_var('phpself', $_CONF['site_admin_url'] .'/plugins/forum/ips.php');
+    $p->set_var('lang_noip', $LANG_GF96['noip']);
+    $p->set_var('LANG_IP',$LANG_GF96['ipbanned']);
+    $p->set_var('lang_ban', $LANG_GF96['ban']);
+    $p->set_var('lang_ip2', $LANG_GF96['ip']);
+    $p->set_var('legend', $LANG_GF96['enterip']);
+    $p->set_var('msg', $LANG_GF96['banipmsg']);
+    $p->set_var('LANG_Actions', $LANG_GF01['ACTIONS']);
     $i = 1;
     while($A = DB_fetchArray($bannedsql)) {
-        $p->set_var ('ip', $A['host_ip']);
-        $p->set_var ('unban', $LANG_GF96['unban']);
-        $p->set_var ('csscode', $i);
-        $p->parse ('ip_records', 'records',true);
+        $p->set_var('ip', $A['host_ip']);
+        $p->set_var('unban', $LANG_GF96['unban']);
+        $p->set_var('csscode', $i);
+        $p->parse('ip_records', 'records',true);
         $i = ($i == 1 ) ? 2 : 1;
     }
     $p->set_var('gltoken_name', CSRF_TOKEN);
     $p->set_var('gltoken', SEC_createToken());
-    $p->parse ('output', 'page');
-    $display .= $p->finish ($p->get_var('output'));
+    $p->parse('output', 'page');
+    $display .= $p->finish($p->get_var('output'));
 }
 
 $display .= COM_endBlock();
 $display .= adminfooter();
-$display .= COM_siteFooter();
+$display = COM_createHTMLDocument($display);
 
 // Show output
 COM_output($display);
