@@ -70,7 +70,7 @@ function emailpassword ($username, $msg = 0)
 
     $retval = '';
 
-    $username = addslashes ($username);
+    $username = DB_escapeString($username);
     // don't retrieve any remote users!
     $result = DB_query ("SELECT uid,email,status FROM {$_TABLES['users']} WHERE username = '$username' AND ((remoteservice is null) OR (remoteservice = ''))");
     $nrows = DB_numRows ($result);
@@ -91,9 +91,7 @@ function emailpassword ($username, $msg = 0)
             $retval = COM_refresh ("{$_CONF['site_url']}/index.php?msg=1");
         }
     } else {
-        $retval = COM_siteHeader ('menu', $LANG04[17])
-                . defaultform ($LANG04[17])
-                . COM_siteFooter ();
+        $retval = COM_createHTMLDocument(defaultform($LANG04[17]), array('pagetitle' => $LANG04[17]));
     }
 
     return $retval;
@@ -146,8 +144,7 @@ function requestpassword($username)
         $retval .= COM_refresh ($_CONF['site_url'] . "/index.php?msg=$msg");
         COM_updateSpeedlimit ('password');
     } else {
-        $retval .= COM_siteHeader ('menu', $LANG04[17])
-                . defaultform ($LANG04[17]) . COM_siteFooter ();
+        $retval = COM_createHTMLDocument(defaultform($LANG04[17]), array('pagetitle' => $LANG04[17]));
     }
 
     return $retval;
@@ -216,8 +213,8 @@ function createuser ($username, $email, $email_conf)
             && (strlen ($username) <= 16)) {
 
         $ucount = DB_count ($_TABLES['users'], 'username',
-                            addslashes ($username));
-        $ecount = DB_count ($_TABLES['users'], 'email', addslashes ($email));
+                            DB_escapeString($username));
+        $ecount = DB_count ($_TABLES['users'], 'email', DB_escapeString($email));
 
         if ($ucount == 0 AND $ecount == 0) {
 
@@ -228,9 +225,7 @@ function createuser ($username, $email, $email_conf)
                 $ret = CUSTOM_userCheck ($username, $email);
                 if (!empty ($ret)) {
                     // no, it's not okay with the custom userform
-                    $retval = COM_siteHeader ('menu')
-                            . CUSTOM_userForm ($ret['string'])
-                            . COM_siteFooter ();
+                    $retval = COM_createHTMLDocument(CUSTOM_userForm($ret['string']));
 
                     return $retval;
                 }
@@ -239,13 +234,12 @@ function createuser ($username, $email, $email_conf)
             // Let plugins have a chance to decide what to do before creating the user, return errors.
             $msg = PLG_itemPreSave ('registration', $username);
             if (!empty ($msg)) {
-                $retval .= COM_siteHeader ('menu', $LANG04[22]);
                 if ($_CONF['custom_registration'] && function_exists ('CUSTOM_userForm')) {
                     $retval .= CUSTOM_userForm ($msg);
                 } else {
                     $retval .= newuserform ($msg);
                 }
-                $retval .= COM_siteFooter();
+                $retval = COM_createHTMLDocument($retval, array('pagetitle' => $LANG04[22]));
 
                 return $retval;
             }
@@ -266,24 +260,22 @@ function createuser ($username, $email, $email_conf)
 
             return $retval;
         } else {
-            $retval .= COM_siteHeader ('menu', $LANG04[22]);
             if ($_CONF['custom_registration'] &&
                     function_exists ('CUSTOM_userForm')) {
                 $retval .= CUSTOM_userForm ($LANG04[19]);
             } else {
                 $retval .= newuserform ($LANG04[19]);
             }
-            $retval .= COM_siteFooter ();
+            $retval = COM_createHTMLDocument($retval, array('pagetitle' => $LANG04[22]));
         }
     } else if ($email !== $email_conf) {
         $msg = $LANG04[125];
-        $retval .= COM_siteHeader ('menu', $LANG04[22]);
         if ($_CONF['custom_registration'] && function_exists('CUSTOM_userForm')) {
             $retval .= CUSTOM_userForm ($msg);
         } else {
             $retval .= newuserform ($msg);
         }
-        $retval .= COM_siteFooter();
+        $retval = COM_createHTMLDocument($retval, array('pagetitle' => $LANG04[22]));
     } else { // invalid username or email address
 
         if ((empty ($username)) || (strlen($username) > 16)) {
@@ -291,13 +283,12 @@ function createuser ($username, $email, $email_conf)
         } else {
             $msg = $LANG04[18]; // invalid email address
         }
-        $retval .= COM_siteHeader ('menu', $LANG04[22]);
         if ($_CONF['custom_registration'] && function_exists('CUSTOM_userForm')) {
             $retval .= CUSTOM_userForm ($msg);
         } else {
             $retval .= newuserform ($msg);
         }
-        $retval .= COM_siteFooter();
+        $retval = COM_createHTMLDocument($retval, array('pagetitle' => $LANG04[22]));
     }
 
     return $retval;
@@ -330,7 +321,10 @@ function loginform($hide_forgotpw_link = false, $userstatus = -1)
         $cfg['message'] = $LANG04[117];
         $cfg['hide_forgotpw_link'] = true;
         $cfg['no_newreg_link']     = true;
-    } else {
+    } elseif ($userstatus == -2) { // No error user just visited page to login
+        $cfg['title']   = $LANG04['user_login'];
+        $cfg['message'] = $LANG04['user_login_message'];
+    } else { // Status should be -1 which is login error        
         $cfg['title']   = $LANG04[65];
         $cfg['message'] = $LANG04[66];
     }
@@ -352,10 +346,7 @@ function newuserform ($msg = '')
     $retval = '';
 
     if (!empty ($msg)) {
-        $retval .= COM_startBlock ($LANG04[21], '',
-                           COM_getBlockTemplate ('_msg_block', 'header'))
-                . $msg
-                . COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
+        $retval .= COM_showMessageText($msg, $LANG04[21]);
     }
     $user_templates = COM_newTemplate($_CONF['path_layout'] . 'users');
     $user_templates->set_file('regform', 'registrationform.thtml');
@@ -468,12 +459,8 @@ function displayLoginErrorAndAbort($msg, $message_title, $message_text)
         // and need to control the login process
         CUSTOM_loginErrorHandler($msg);
     } else {
-        $retval = COM_siteHeader('menu', $message_title)
-                . COM_startBlock($message_title, '',
-                                 COM_getBlockTemplate('_msg_block', 'header'))
-                . $message_text
-                . COM_endBlock(COM_getBlockTemplate('_msg_block', 'footer'))
-                . COM_siteFooter();
+        $retval = COM_showMessageText($message_text, $message_title);
+        $retval = COM_createHTMLDocument($retval, array('pagetitle' => $message_title));
 
         header($_SERVER['SERVER_PROTOCOL'] . ' 403 Forbidden');
         header('Status: 403 Forbidden');
@@ -649,14 +636,14 @@ case 'profile':
         }
         $display .= USER_showProfile($uid, false, $msg, $plugin);
     } else {
-        $display .= COM_refresh ($_CONF['site_url'] . '/index.php');
+        COM_handle404();
     }
     break;
 
 case 'user':
     $username = COM_applyFilter ($_GET['username']);
     if (!empty ($username)) {
-        $username = addslashes ($username);
+        $username = DB_escapeString($username);
         $uid = DB_getItem ($_TABLES['users'], 'uid', "username = '$username'");
         if ($uid > 1) {
             $display .= USER_showProfile($uid);
@@ -670,12 +657,8 @@ case 'user':
 
 case 'create':
     if ($_CONF['disable_new_user_registration']) {
-        $display .= COM_siteHeader ('menu', $LANG04[22]);
-        $display .= COM_startBlock ($LANG04[22], '',
-                            COM_getBlockTemplate ('_msg_block', 'header'))
-                 . $LANG04[122]
-                 . COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
-        $display .= COM_siteFooter ();
+        $display .= COM_showMessageText($LANG04[122], $LANG04[22]);
+        $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG04[22]));
     } else {
         $email = COM_applyFilter ($_POST['email']);
         $email_conf = COM_applyFilter ($_POST['email_conf']);
@@ -684,21 +667,20 @@ case 'create':
     break;
 
 case 'getpassword':
-    $display .= COM_siteHeader ('menu', $LANG04[25]);
     if ($_CONF['passwordspeedlimit'] == 0) {
         $_CONF['passwordspeedlimit'] = 300; // 5 minutes
     }
     COM_clearSpeedlimit ($_CONF['passwordspeedlimit'], 'password');
     $last = COM_checkSpeedlimit ('password');
     if ($last > 0) {
-        $display .= COM_startBlock ($LANG12[26], '',
-                            COM_getBlockTemplate ('_msg_block', 'header'))
-                 . sprintf ($LANG04[93], $last, $_CONF['passwordspeedlimit'])
-                 . COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
+        $display .= COM_showMessageText(
+                        sprintf($LANG04[93], $last, $_CONF['passwordspeedlimit']),
+                        $LANG12[26]
+        );
     } else {
         $display .= getpasswordform ();
     }
-    $display .= COM_siteFooter ();
+    $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG04[25]));
     break;
 
 case 'newpwd':
@@ -709,14 +691,12 @@ case 'newpwd':
         $valid = DB_count ($_TABLES['users'], array ('uid', 'pwrequestid'),
                            array ($uid, $reqid));
         if ($valid == 1) {
-            $display .= COM_siteHeader ('menu', $LANG04[92]);
             $display .= newpasswordform ($uid, $reqid);
-            $display .= COM_siteFooter ();
+            $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG04[92]));
         } else { // request invalid or expired
-            $display .= COM_siteHeader ('menu', $LANG04[25]);
             $display .= COM_showMessage (54);
             $display .= getpasswordform ();
-            $display .= COM_siteFooter ();
+            $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG04[25]));
         }
     } else {
         // this request doesn't make sense - ignore it
@@ -738,18 +718,16 @@ case 'setnewpwd':
             $valid = DB_count ($_TABLES['users'], array ('uid', 'pwrequestid'),
                                array ($uid, $reqid));
             if ($valid == 1) {
-                $passwd = SEC_encryptPassword($_POST['passwd']);
-                DB_change ($_TABLES['users'], 'passwd', "$passwd",
-                           "uid", $uid);
+                SEC_updateUserPassword($_POST['passwd'], $uid);
+
                 DB_delete ($_TABLES['sessions'], 'uid', $uid);
                 DB_change ($_TABLES['users'], 'pwrequestid', "NULL",
                            'uid', $uid);
                 $display = COM_refresh ($_CONF['site_url'] . '/users.php?msg=53');
             } else { // request invalid or expired
-                $display .= COM_siteHeader ('menu', $LANG04[25]);
                 $display .= COM_showMessage (54);
                 $display .= getpasswordform ();
-                $display .= COM_siteFooter ();
+                $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG04[25]));
             }
         } else {
             // this request doesn't make sense - ignore it
@@ -765,12 +743,11 @@ case 'emailpasswd':
     COM_clearSpeedlimit ($_CONF['passwordspeedlimit'], 'password');
     $last = COM_checkSpeedlimit ('password');
     if ($last > 0) {
-        $display .= COM_siteHeader ('menu', $LANG12[26])
-                 . COM_startBlock ($LANG12[26], '',
-                           COM_getBlockTemplate ('_msg_block', 'header'))
-                 . sprintf ($LANG04[93], $last, $_CONF['passwordspeedlimit'])
-                 . COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'))
-                 . COM_siteFooter ();
+        $display .= COM_showMessageText(
+                        sprintf($LANG04[93], $last, $_CONF['passwordspeedlimit']),
+                        $LANG12[26]
+        );
+        $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG12[26]));
     } else {
         $username = COM_applyFilter ($_POST['username']);
         $email = COM_applyFilter ($_POST['email']);
@@ -788,12 +765,8 @@ case 'emailpasswd':
     break;
 
 case 'new':
-    $display .= COM_siteHeader ('menu', $LANG04[22]);
     if ($_CONF['disable_new_user_registration']) {
-        $display .= COM_startBlock ($LANG04[22], '',
-                            COM_getBlockTemplate ('_msg_block', 'header'))
-                 . $LANG04[122]
-                 . COM_endBlock (COM_getBlockTemplate ('_msg_block', 'footer'));
+        $display .= COM_showMessageText($LANG04[122], $LANG04[22]);
     } else {
         // Call custom registration and account record create function
         // if enabled and exists
@@ -803,7 +776,9 @@ case 'new':
             $display .= newuserform();
         }
     }
-    $display .= COM_siteFooter();
+
+    $display = COM_createHTMLDocument($display, array('pagetitle' => $LANG04[22]));
+    
     break;
 
 case 'tokenexpired':
@@ -918,16 +893,14 @@ default:
             !$_CONF['disable_new_user_registration'] &&
             isset($_GET['oauth_login'])) {
         // Here we go with the handling of OAuth authentification.
-
-        $active_service = false;
         $modules = SEC_collectRemoteOAuthModules();
         $active_service = (count($modules) == 0) ? false : in_array($_GET['oauth_login'], $modules);
         if (!$active_service) {
             $status = -1;
+            COM_errorLog("OAuth login failed - there was no consumer available for the service:" . $_GET['oauth_login']);
         } else {
             $query = array_merge($_GET, $_POST);
             $service = $query['oauth_login'];
-            $callback_url = $_CONF['site_url'] . '/users.php?oauth_login=' . $service;
 
             COM_clearSpeedlimit($_CONF['login_speedlimit'], $service);
             if (COM_checkSpeedlimit($service, $_CONF['login_attempts']) > 0) {
@@ -937,42 +910,23 @@ default:
             require_once $_CONF['path_system'] . 'classes/oauthhelper.class.php';
 
             $consumer = new OAuthConsumer($service);
-            $callback_query_string = $consumer->getCallback_query_string();
-            $cancel_query_string = $consumer->getCancel_query_string();
 
-            if (!isset($query[$callback_query_string]) && (empty($cancel_query_string) || !isset($query[$cancel_query_string]))) {
-                $url = $consumer->find_identity_info($callback_url, $query);
-                if (empty($url)) {
-                    COM_updateSpeedlimit('login');
-                    COM_updateSpeedlimit($service);
-                    echo COM_refresh($_CONF['site_url'] . '/users.php?msg=110');
-                    exit;
-                } else {
-                    header('Location: ' . $url);
-                    exit;
-                }
-            } elseif (isset($query[$callback_query_string])) {
-                $oauth_userinfo = $consumer->sreq_userinfo_response($query);
-                if (empty($oauth_userinfo)) {
-                    COM_updateSpeedlimit('login');
-                    echo COM_refresh($_CONF['site_url'] . '/users.php?msg=111');
-                    exit;
-                } else {
-                    $consumer->doAction($oauth_userinfo);
-                }
-            } elseif (!empty($cancel_query_string) && isset($query[$cancel_query_string])) {
-                    COM_updateSpeedlimit('login');
-                    echo COM_refresh($_CONF['site_url'] . '/users.php?msg=112');
-                    exit;
-            } else {
+            $callback_url = $_CONF['site_url'] . '/users.php?oauth_login=' . $service;
+
+            $consumer->setRedirectURL($callback_url);
+            $oauth_userinfo = $consumer->authenticate_user();
+            if ( $oauth_userinfo === false ) {
                 COM_updateSpeedlimit('login');
-                echo COM_refresh($_CONF['site_url'] . '/users.php?msg=91');
+                COM_errorLog("OAuth Error: " . $consumer->error);
+                echo COM_refresh($_CONF['site_url'] . '/users.php?msg=110'); // OAuth authentication error
                 exit;
             }
-        }
 
+            $consumer->doAction($oauth_userinfo);
+
+        }        
     } else {
-        $status = -1;
+        $status = -2; // User just visited login page no error. -1 = error
     }
 
     if ($status == USER_ACCOUNT_ACTIVE) { // logged in AOK.
@@ -987,7 +941,7 @@ default:
         PLG_loginUser ($_USER['uid']);
 
         // Now that we handled session cookies, handle longterm cookie
-        if (!isset($_COOKIE[$_CONF['cookie_name']]) || !isset($_COOKIE['password'])) {
+        if (!isset($_COOKIE[$_CONF['cookie_name']]) || !isset($_COOKIE['cookie_password'])) {
             // Either their cookie expired or they are new
             $cooktime = COM_getUserCookieTimeout();
             if ($VERBOSE) {
@@ -1057,8 +1011,6 @@ default:
             COM_updateSpeedlimit('login');
         }
 
-        $display .= COM_siteHeader('menu');
-
         $msg = 0;
         if (isset($_REQUEST['msg'])) {
             $msg = COM_applyFilter($_REQUEST['msg'], true);
@@ -1134,20 +1086,27 @@ default:
                 displayLoginErrorAndAbort(82, $LANG04[113], $LANG04[112]);
             } else { // Show login form
                 if(($msg != 69) && ($msg != 70)) {
-                    if ($_CONF['custom_registration'] AND
-                            function_exists('CUSTOM_loginErrorHandler')) {
-                        // Typically this will be used if you have a custom
-                        // main site page and need to control the login process
-                        $display .= CUSTOM_loginErrorHandler($msg);
+                    if (COM_isAnonUser()) {
+                        if ($_CONF['custom_registration'] AND
+                                function_exists('CUSTOM_loginErrorHandler')) {
+                            // Typically this will be used if you have a custom
+                            // main site page and need to control the login process
+                            $display .= CUSTOM_loginErrorHandler($msg);
+                        } else {
+                            $display .= loginform(false, $status);
+                        }
                     } else {
-                        $display .= loginform(false, $status);
+                        // user is already logged in
+                        $display .= COM_startBlock ($LANG04['user_login']);
+                        $display .= '<p>' . $LANG04['user_logged_in_message'] . '</p>';
+                        $display .= COM_endBlock ();
                     }
                 }
             }
             break;
         }
 
-        $display .= COM_siteFooter();
+        $display = COM_createHTMLDocument($display);
     }
     break;
 }
